#!/bin/sh
# Copyright (c) 2006 TeamF1, Inc.
# All rights reserved.
#
# This script captures the state of a VPN router to be downloaded
# and sent to TeamF1 for field support.
#

# Validate Session
/work/pfrm1.0/sessionValidate
if [ $? != 0 ]; then
    exit 0
fi

#
# HTTP content type
echo "Content-type: application/gzip"
echo "Content-disposition: attachment; filename=`hostname`dbg.tgz"
echo

logdir="/var"
tmpfile=/tmp/dbgerr.log
#
# create a temp log directory
echo mkdir -p $logdir/dbg > $tmpfile 2> $tmpfile

mkdir -p $logdir/dbg > $tmpfile 2> $tmpfile

# Run each command and log to a tmp file. The tmpfile will be
# put in the tar file so that we can examine the execution
# of these commands themselves


# This is the dir where temp log files are created
cd $logdir/dbg/

# Run a bunch of commands to capture the state of the box
# time we started
date > time.log 2>> $tmpfile

# Since uptime is not supported, we can calculate the 
# up time from system timer interrupts. This will be 
# approx. value.
cat /proc/interrupts > interrupts.log 2>> $tmpfile
sleep 1;
cat /proc/interrupts >> interrupts.log 2>> $tmpfile
sleep 1;
cat /proc/interrupts >> interrupts.log 2>> $tmpfile

# Process state
 ps                         > ps.log 2>> $tmpfile

# network state
 route -n                 > route.log 2>> $tmpfile
 ifconfig -a              > ifconfig.log 2>> $tmpfile
 netstat -n               > netstat.log 2>> $tmpfile

# ipsec
 setkey -DP               > ipsecSP.log 2>> $tmpfile
 setkey -Da               > ipsecSA.log 2>> $tmpfile

# firewall, NAT, etc.
 iptables -L -v -n           > iptables.log 2>> $tmpfile
 ipset -L -n                 > ipset.log 2>> $tmpfile
 iptables -t nat -L -v -n    > nat.log 2>> $tmpfile
 iptables -t mangle -L -v -n > mangle.log 2>> $tmpfile
 ipset -L -n                 > ipset.log 2>> $tmpfile
 cat /proc/sys/net/ipv4/netfilter/ip_conntrack_count > conntrack.log 2>> $tmpfile
 cat /proc/net/stat/ip_conntrack  >> conntrack.log 2>> $tmpfile
 cat /proc/net/ip_conntrack | wc -l  >> conntrack.log 2>> $tmpfile
 cat /proc/net/ip_conntrack  >> conntrack.log 2>> $tmpfile
 cat /proc/meminfo          > meminfo.log 2>> $tmpfile
 uptime                     > loadavg.log 2>> $tmpfile

 ip route show             > route.log 2>> $tmpfile
 ip route show table 10    >> route.log 2>> $tmpfile
 ip route show table 20    >> route.log 2>> $tmpfile
 ip route show table 30    >> route.log 2>> $tmpfile
 ip route show table 40    >> route.log 2>> $tmpfile
 ip route show table 100   >> route.log 2>> $tmpfile
 ip route show table 200   >> route.log 2>> $tmpfile
 ip rule  show             >> route.log 2>> $tmpfile

 cat /proc/net/stat/arp_cache > arp.log 2>> $tmpfile
 cat /proc/net/arp >> arp.log 2>> $tmpfile

 dmesg                         > dmesg.log 2>> $tmpfile

# Tar up all the files we need for debugging
# errors from tar will be ignored..

if [ -h "/var/log" ]; then 
# When /var/log is a symbolic link instead of a directory, 
# we take system logs from /tmp/system
    tar czf - /var $tmpfile /tmp/
else
tar czf - /var $tmpfile
fi

#cleanup
rm -fr $logdir/dbg $tmpfile

# Done
exit

